==> sharyn-10.10.0.tgz: package/redux/create-reducer.test.js <==
"use strict";

var _interopRequireDefault = require("@babel/runtime-corejs2/helpers/interopRequireDefault");

var _objectSpread2 = _interopRequireDefault(require("@babel/runtime-corejs2/helpers/objectSpread"));

var _createReducer = _interopRequireDefault(require("./create-reducer"));

test('defaultReducer', function () {
  expect((0, _createReducer.default)()()).toEqual({});
  expect((0, _createReducer.default)(undefined, 'initial')()).toBe('initial');
  expect((0, _createReducer.default)([['a', function () {
    return function () {
      return 'A';
    };
  }]])(null, {
    type: 'a'
  })).toBe('A');
  expect((0, _createReducer.default)([['a', function () {
    return function () {
      return 'A';
    };
  }]])(null, {
    type: 'b'
  })).toBe(null);
  expect((0, _createReducer.default)([['a', function () {
    return function () {
      return 'A';
    };
  }]])(undefined, {
    type: 'b'
  })).toEqual({});

  var reduction1 = function reduction1() {
    return function (state) {
      return (0, _objectSpread2.default)({}, state, {
        bar: 'bar'
      });
    };
  };

  var case1 = ['a', reduction1];
  expect((0, _createReducer.default)([case1])({
    foo: 'foo'
  }, {
    type: 'a'
  })).toEqual({
    foo: 'foo',
    bar: 'bar'
  });

  var reduction2 = function reduction2(payload) {
    return function (state) {
      return (0, _objectSpread2.default)({}, state, {
        bar: payload
      });
    };
  };

  var case2 = ['a', reduction2];

  var errorReduction = function errorReduction() {
    return function () {
      throw Error('This should not get executed but it was');
    };
  };

  var errorCase = ['x', errorReduction];
  expect((0, _createReducer.default)([errorCase, case2])({
    foo: 'foo'
  }, {
    type: 'a',
    payload: 'payload'
  })).toEqual({
    foo: 'foo',
    bar: 'payload'
  });
});

==> sharyn-11.4.0.tgz: package/redux/create-reducer.test.js <==
"use strict";

var _interopRequireDefault = require("@babel/runtime-corejs2/helpers/interopRequireDefault");

var _objectSpread2 = _interopRequireDefault(require("@babel/runtime-corejs2/helpers/objectSpread"));

var _createReducer = _interopRequireDefault(require("./create-reducer"));

test('defaultReducer', function () {
  expect((0, _createReducer["default"])()()).toEqual({});
  expect((0, _createReducer["default"])(undefined, 'initial')()).toBe('initial');
  expect((0, _createReducer["default"])([['a', function () {
    return function () {
      return 'A';
    };
  }]])(null, {
    type: 'a'
  })).toBe('A');
  expect((0, _createReducer["default"])([['a', function () {
    return function () {
      return 'A';
    };
  }]])(null, {
    type: 'b'
  })).toBe(null);
  expect((0, _createReducer["default"])([['a', function () {
    return function () {
      return 'A';
    };
  }]])(undefined, {
    type: 'b'
  })).toEqual({});

  var reduction1 = function reduction1() {
    return function (state) {
      return (0, _objectSpread2["default"])({}, state, {
        bar: 'bar'
      });
    };
  };

  var case1 = ['a', reduction1];
  expect((0, _createReducer["default"])([case1])({
    foo: 'foo'
  }, {
    type: 'a'
  })).toEqual({
    foo: 'foo',
    bar: 'bar'
  });

  var reduction2 = function reduction2(payload) {
    return function (state) {
      return (0, _objectSpread2["default"])({}, state, {
        bar: payload
      });
    };
  };

  var case2 = ['a', reduction2];

  var errorReduction = function errorReduction() {
    return function () {
      throw Error('This should not get executed but it was');
    };
  };

  var errorCase = ['x', errorReduction];
  expect((0, _createReducer["default"])([errorCase, case2])({
    foo: 'foo'
  }, {
    type: 'a',
    payload: 'payload'
  })).toEqual({
    foo: 'foo',
    bar: 'payload'
  });
});
